# StreamsUpdateList

Object containing a list of stream objects with information to update
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**streams** | [**list[StreamUpdate]**](StreamUpdate.md) | List of Streams to update | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


